from distutils.core import setup

setup(
    name      ="helloqinfei",
    version    ="1.0.0",
    py_modules=["helloqinfei"],
    author     ="qinfei",
    author_email="iqinfei@163.com",
    url="http://qinfei.glrsmart.com",
    description="this is a pypi test file",
    )
